<?php
// VKy[W͉ʂ\
$gOut['body'] = '<form method=POST action='.$_SERVER['PHP_SELF'].'>'
. 'VKy[W<br>'
. '<input name="title" size="20" maxlength="20"><br>'
. '<input type="submit" value="쐬"><input type="hidden" name="a" value="N"></form>'
?>